@@ -1,4 +1,4 @@
-"""
+'''
 # AWS AutoScaling Common Library
 
 <!--BEGIN STABILITY BANNER-->---
@@ -20,7 +20,7 @@ This is a sister package to `@aws-cdk/aws-autoscaling` and
 details between them.
 
 It does not need to be used directly.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -49,12 +49,12 @@ class Alarms:
         lower_alarm_interval_index: typing.Optional[jsii.Number] = None,
         upper_alarm_interval_index: typing.Optional[jsii.Number] = None,
     ) -> None:
-        """
+        '''
         :param lower_alarm_interval_index: 
         :param upper_alarm_interval_index: 
 
         :stability: experimental
-        """
+        '''
         self._values: typing.Dict[str, typing.Any] = {}
         if lower_alarm_interval_index is not None:
             self._values["lower_alarm_interval_index"] = lower_alarm_interval_index
@@ -63,19 +63,19 @@ class Alarms:
 
     @builtins.property
     def lower_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("lower_alarm_interval_index")
-        return result
+        return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
     def upper_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("upper_alarm_interval_index")
-        return result
+        return typing.cast(typing.Optional[jsii.Number], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -101,12 +101,12 @@ class ArbitraryIntervals:
         absolute: builtins.bool,
         intervals: typing.List["ScalingInterval"],
     ) -> None:
-        """
+        '''
         :param absolute: 
         :param intervals: 
 
         :stability: experimental
-        """
+        '''
         self._values: typing.Dict[str, typing.Any] = {
             "absolute": absolute,
             "intervals": intervals,
@@ -114,21 +114,21 @@ class ArbitraryIntervals:
 
     @builtins.property
     def absolute(self) -> builtins.bool:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("absolute")
         assert result is not None, "Required property 'absolute' is missing"
-        return result
+        return typing.cast(builtins.bool, result)
 
     @builtins.property
     def intervals(self) -> typing.List["ScalingInterval"]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("intervals")
         assert result is not None, "Required property 'intervals' is missing"
-        return result
+        return typing.cast(typing.List["ScalingInterval"], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -155,13 +155,13 @@ class CompleteScalingInterval:
         upper: jsii.Number,
         change: typing.Optional[jsii.Number] = None,
     ) -> None:
-        """
+        '''
         :param lower: 
         :param upper: 
         :param change: 
 
         :stability: experimental
-        """
+        '''
         self._values: typing.Dict[str, typing.Any] = {
             "lower": lower,
             "upper": upper,
@@ -171,29 +171,29 @@ class CompleteScalingInterval:
 
     @builtins.property
     def lower(self) -> jsii.Number:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("lower")
         assert result is not None, "Required property 'lower' is missing"
-        return result
+        return typing.cast(jsii.Number, result)
 
     @builtins.property
     def upper(self) -> jsii.Number:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("upper")
         assert result is not None, "Required property 'upper' is missing"
-        return result
+        return typing.cast(jsii.Number, result)
 
     @builtins.property
     def change(self) -> typing.Optional[jsii.Number]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("change")
-        return result
+        return typing.cast(typing.Optional[jsii.Number], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -209,55 +209,55 @@ class CompleteScalingInterval:
 
 @jsii.interface(jsii_type="@aws-cdk/aws-autoscaling-common.IRandomGenerator")
 class IRandomGenerator(typing_extensions.Protocol):
-    """
+    '''
     :stability: experimental
-    """
+    '''
 
     @builtins.staticmethod
-    def __jsii_proxy_class__():
+    def __jsii_proxy_class__() -> typing.Type["_IRandomGeneratorProxy"]:
         return _IRandomGeneratorProxy
 
     @jsii.member(jsii_name="nextBoolean")
     def next_boolean(self) -> builtins.bool:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         ...
 
     @jsii.member(jsii_name="nextInt")
     def next_int(self, min: jsii.Number, max: jsii.Number) -> jsii.Number:
-        """
+        '''
         :param min: -
         :param max: -
 
         :stability: experimental
-        """
+        '''
         ...
 
 
 class _IRandomGeneratorProxy:
-    """
+    '''
     :stability: experimental
-    """
+    '''
 
     __jsii_type__: typing.ClassVar[str] = "@aws-cdk/aws-autoscaling-common.IRandomGenerator"
 
     @jsii.member(jsii_name="nextBoolean")
     def next_boolean(self) -> builtins.bool:
-        """
+        '''
         :stability: experimental
-        """
-        return jsii.invoke(self, "nextBoolean", [])
+        '''
+        return typing.cast(builtins.bool, jsii.invoke(self, "nextBoolean", []))
 
     @jsii.member(jsii_name="nextInt")
     def next_int(self, min: jsii.Number, max: jsii.Number) -> jsii.Number:
-        """
+        '''
         :param min: -
         :param max: -
 
         :stability: experimental
-        """
-        return jsii.invoke(self, "nextInt", [min, max])
+        '''
+        return typing.cast(jsii.Number, jsii.invoke(self, "nextInt", [min, max]))
 
 
 @jsii.data_type(
@@ -273,14 +273,14 @@ class ScalingInterval:
         lower: typing.Optional[jsii.Number] = None,
         upper: typing.Optional[jsii.Number] = None,
     ) -> None:
-        """(experimental) A range of metric values in which to apply a certain scaling operation.
+        '''(experimental) A range of metric values in which to apply a certain scaling operation.
 
         :param change: (experimental) The capacity adjustment to apply in this interval. The number is interpreted differently based on AdjustmentType: - ChangeInCapacity: add the adjustment to the current capacity. The number can be positive or negative. - PercentChangeInCapacity: add or remove the given percentage of the current capacity to itself. The number can be in the range [-100..100]. - ExactCapacity: set the capacity to this number. The number must be positive.
         :param lower: (experimental) The lower bound of the interval. The scaling adjustment will be applied if the metric is higher than this value. Default: Threshold automatically derived from neighbouring intervals
         :param upper: (experimental) The upper bound of the interval. The scaling adjustment will be applied if the metric is lower than this value. Default: Threshold automatically derived from neighbouring intervals
 
         :stability: experimental
-        """
+        '''
         self._values: typing.Dict[str, typing.Any] = {
             "change": change,
         }
@@ -291,7 +291,7 @@ class ScalingInterval:
 
     @builtins.property
     def change(self) -> jsii.Number:
-        """(experimental) The capacity adjustment to apply in this interval.
+        '''(experimental) The capacity adjustment to apply in this interval.
 
         The number is interpreted differently based on AdjustmentType:
 
@@ -303,36 +303,36 @@ class ScalingInterval:
           be positive.
 
         :stability: experimental
-        """
+        '''
         result = self._values.get("change")
         assert result is not None, "Required property 'change' is missing"
-        return result
+        return typing.cast(jsii.Number, result)
 
     @builtins.property
     def lower(self) -> typing.Optional[jsii.Number]:
-        """(experimental) The lower bound of the interval.
+        '''(experimental) The lower bound of the interval.
 
         The scaling adjustment will be applied if the metric is higher than this value.
 
         :default: Threshold automatically derived from neighbouring intervals
 
         :stability: experimental
-        """
+        '''
         result = self._values.get("lower")
-        return result
+        return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
     def upper(self) -> typing.Optional[jsii.Number]:
-        """(experimental) The upper bound of the interval.
+        '''(experimental) The upper bound of the interval.
 
         The scaling adjustment will be applied if the metric is lower than this value.
 
         :default: Threshold automatically derived from neighbouring intervals
 
         :stability: experimental
-        """
+        '''
         result = self._values.get("upper")
-        return result
+        return typing.cast(typing.Optional[jsii.Number], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
